summaryrefslogtreecommitdiffstats
path: root/forum/conf/forum_data_rules.py
diff options
context:
space:
mode:
Diffstat (limited to 'forum/conf/forum_data_rules.py')
-rw-r--r--forum/conf/forum_data_rules.py6
1 files changed, 3 insertions, 3 deletions
diff --git a/forum/conf/forum_data_rules.py b/forum/conf/forum_data_rules.py
index e452ea7b..f9c4afda 100644
--- a/forum/conf/forum_data_rules.py
+++ b/forum/conf/forum_data_rules.py
@@ -2,8 +2,8 @@
Settings for forum data display and entry
"""
from forum.conf.settings_wrapper import settings
-from livesettings import ConfigurationGroup, BooleanValue, IntegerValue
-from livesettings import StringValue
+from forum.deps.livesettings import ConfigurationGroup, BooleanValue, IntegerValue
+from forum.deps.livesettings import StringValue
from django.utils.translation import ugettext as _
from forum import const
@@ -39,7 +39,7 @@ settings.register(
)
)
#todo: looks like there is a bug in livesettings
#that does not allow Integer values with defaults and choices
settings.register(
StringValue(
@@ -39,7 +39,7 @@ settings.register(
)
)
-#todo: looks like there is a bug in livesettings
+#todo: looks like there is a bug in forum.deps.livesettings
#that does not allow Integer values with defaults and choices
settings.register(